Usage
TAQ.CleanTickByTick(dirInput, dirOutput, window = 80, deltaTrimmed = 0.10, granularity = 0.04, useCleaned = TRUE) TAQ.Aggregate(dirInput, symbol, bin, useAggregated = TRUE) TAQ.Report(dirInput, symbol)
TAQ.Read(dirInput, symbol, import = NULL, startDate, endDate, bin)
Arguments
dirInput
A character scalar: the input directory.
For the function CleanTickByTick(), dirInput is the name of the folder containing the raw data files.
In this case it is important that dirInput includes only .gz files to be cleaned.
For the remaining functions, dirInput is the name of the folder including the previously cleaned/aggregated data (appearing as dirOutput in the function CleanTickByTick()).
dirOutput
A character scalar: the output directory.
It must be different from dirInput.
window
A numeric integer scalar: the window size for the trimming procedure of data clean (see Details).
deltaTrimmed
A numeric scalar into $(0,1)$: the trimming proportion (see Details).
granularity
A numeric positive scalar: the granularity parameter (see Details).
useCleaned
A logical scalar: if TRUE, previously cleaned files (if any) are not cleaned again.
useAggregated
A logical scalar: if TRUE, previously aggregated data (if any) are not aggregated again.
symbol
A character (vector in TAQ.Aggregate(); scalar in TAQ.Report() and TAQ.Read()): the ticker symbols of interest.
startDate
A numeric integer scalar: the start date in the yyyymmdd format.
endDate
A numeric integer scalar: the end date in the yyyymmdd format.
bin
A numeric integer scalar: the bin size (in seconds) for aggregating data.
import
A character: the list of fields to be imported. One or more among:
"FIRST": First price in the bin.
"MIN": Min price in the bin.
"MAX": Max price in the bin.
"LAST": Last price in the bin.
"SIZE": First price in the bin.
"#TRADES": Number of trades in the bin.
"VWAP": Volume Weighted Average Price in the bin.
If NULL, all fields are imported.